@@ -8,10 +8,19 @@ from treq.testing import StubTreq
 from twisted.internet.defer import inlineCallbacks
 from twisted.python.compat import nativeString
 from twisted.trial.unittest import SynchronousTestCase
+from twisted.web.error import FlattenerError
 from twisted.web.iweb import IRequest
 from twisted.web.template import Element, TagLoader, renderer, tags
 
-from klein import Field, Form, Klein, RenderableForm, Requirer, SessionProcurer
+from klein import (
+    Field,
+    Form,
+    Klein,
+    KleinRenderable,
+    RenderableForm,
+    Requirer,
+    SessionProcurer,
+)
 from klein.interfaces import (
     ISession,
     ISessionStore,
@@ -62,7 +71,23 @@ class TestObject:
         dangling=DanglingField(lambda x: x, "text"),
     )
     def danglingParameter(self, dangling: str) -> None:
-        "..."
+        """
+        Provided to test error reporting on handling of dangling fields.
+
+        @see: L{DanglingField}
+        """
+
+    @requirer.require(
+        router.route("/dangling-param", methods=["GET"]),
+        form=Form.rendererFor(danglingParameter, action="/dangling-param"),
+    )
+    def renderDanglingParameter(self, form: Form) -> Form:
+        """
+        Provided to test error reporting on rendering of dangling fields.
+
+        @see: L{DanglingField}
+        """
+        return form
 
     @requirer.require(
         router.route("/handle", methods=["POST"]),
@@ -168,7 +193,7 @@ class TestObject:
     @requirer.require(
         router.route("/handle-empty", methods=["POST"]),
     )
-    def emptyHandler(self) -> bytes:
+    def emptyHandler(self) -> KleinRenderable:
         """
         Empty form handler; just for testing rendering.
         """
@@ -338,7 +363,10 @@ class TestForms(SynchronousTestCase):
     def test_noName(self) -> None:
         """
         A handler for a Form with a Field that doesn't have a name will return
-        an error explaining the problem.
+        an error explaining the problem when either processed in a handler or
+        rendered in a form.
+
+        @see: L{DanglingField}.
         """
         mem = MemorySessionStore()
         session = self.successResultOf(
@@ -357,7 +385,22 @@ class TestForms(SynchronousTestCase):
         errors = self.flushLoggedErrors(ValueError)
         self.assertEqual(len(errors), 1)
         self.assertIn(
-            str(errors[0].value), "Cannot extract unnamed form field."
+            "Cannot extract unnamed form field.",
+            str(errors[0].value),
+        )
+
+        self.successResultOf(
+            stub.get(
+                "https://localhost/dangling-param",
+                headers={b"X-Test-Session": session.identifier},
+            ),
+        )
+        self.assertEqual(response.code, 500)
+        errors = self.flushLoggedErrors(FlattenerError)
+        self.assertEqual(len(errors), 1)
+        self.assertIn(
+            "Cannot generate tags for unnamed form field.",
+            str(errors[0].value.args[0]),
         )
 
     def test_handlingGET(self) -> None:
